package com.ruoyi.generator.mapper;

import java.util.List;
import com.ruoyi.generator.domain.TemplateFile;

/**
 * 代码模板文件Mapper接口
 *
 * @author ruoyi
 * @date YOUR_CURRENT_DATE
 */
public interface TemplateFileMapper
{
    /**
     * 查询代码模板文件
     *
     * @param templateFileId 代码模板文件主键
     * @return 代码模板文件
     */
    public TemplateFile selectTemplateFileByTemplateFileId(Long templateFileId);

    /**
     * 查询代码模板文件列表
     *
     * @param templateFile 代码模板文件
     * @return 代码模板文件集合
     */
    public List<TemplateFile> selectTemplateFileList(TemplateFile templateFile);

    /**
     * 根据模板ID查询代码模板文件列表
     *
     * @param templateId 模板ID
     * @return 代码模板文件集合
     */
    public List<TemplateFile> selectTemplateFilesByTemplateId(Long templateId);

    /**
     * 新增代码模板文件
     *
     * @param templateFile 代码模板文件
     * @return 结果
     */
    public int insertTemplateFile(TemplateFile templateFile);

    /**
     * 修改代码模板文件
     *
     * @param templateFile 代码模板文件
     * @return 结果
     */
    public int updateTemplateFile(TemplateFile templateFile);

    /**
     * 删除代码模板文件
     *
     * @param templateFileId 代码模板文件主键
     * @return 结果
     */
    public int deleteTemplateFileByTemplateFileId(Long templateFileId);

    /**
     * 批量删除代码模板文件
     *
     * @param templateFileIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTemplateFileByTemplateFileIds(Long[] templateFileIds);

    /**
     * 根据模板ID删除代码模板文件
     *
     * @param templateId 模板ID
     * @return 结果
     */
    public int deleteTemplateFilesByTemplateId(Long templateId);
} 